@@ -107,7 +107,7 @@ Keiji Yoshimi E<lt>walf443 at gmail dot comE<gt>
 
 =head1 SEE ALSO
 
-+<DBIx::Skinny::ProxyTable>, +<DBIx::Skinny::Schema::ProxyTableRule>
+L<DBIx::Skinny::ProxyTable>, L<DBIx::Skinny::Schema::ProxyTableRule>
 
 =head1 LICENSE
 
